# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from h2o_secure_store.gen.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from h2o_secure_store.gen.model.o_auth_client_resource import OAuthClientResource
from h2o_secure_store.gen.model.protobuf_any import ProtobufAny
from h2o_secure_store.gen.model.rpc_status import RpcStatus
from h2o_secure_store.gen.model.secret_state import SecretState
from h2o_secure_store.gen.model.v1_create_o_auth_client_response import V1CreateOAuthClientResponse
from h2o_secure_store.gen.model.v1_create_secret_response import V1CreateSecretResponse
from h2o_secure_store.gen.model.v1_create_secret_version_response import V1CreateSecretVersionResponse
from h2o_secure_store.gen.model.v1_create_token_source_response import V1CreateTokenSourceResponse
from h2o_secure_store.gen.model.v1_delete_secret_response import V1DeleteSecretResponse
from h2o_secure_store.gen.model.v1_get_o_auth_client_response import V1GetOAuthClientResponse
from h2o_secure_store.gen.model.v1_get_secret_response import V1GetSecretResponse
from h2o_secure_store.gen.model.v1_get_secret_version_response import V1GetSecretVersionResponse
from h2o_secure_store.gen.model.v1_get_token_source_response import V1GetTokenSourceResponse
from h2o_secure_store.gen.model.v1_list_o_auth_clients_response import V1ListOAuthClientsResponse
from h2o_secure_store.gen.model.v1_list_secret_versions_response import V1ListSecretVersionsResponse
from h2o_secure_store.gen.model.v1_list_secrets_response import V1ListSecretsResponse
from h2o_secure_store.gen.model.v1_list_token_sources_response import V1ListTokenSourcesResponse
from h2o_secure_store.gen.model.v1_o_auth_client import V1OAuthClient
from h2o_secure_store.gen.model.v1_reveal_secret_version_value_response import V1RevealSecretVersionValueResponse
from h2o_secure_store.gen.model.v1_secret import V1Secret
from h2o_secure_store.gen.model.v1_secret_version import V1SecretVersion
from h2o_secure_store.gen.model.v1_token_source import V1TokenSource
from h2o_secure_store.gen.model.v1_undelete_secret_response import V1UndeleteSecretResponse
from h2o_secure_store.gen.model.v1_update_o_auth_client_response import V1UpdateOAuthClientResponse



from h2o_secure_store.gen.ai.h2o.securestore.v1 import secret_pb2 as _secret_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.api import resource_pb2 as _resource_pb2
from google.api import client_pb2 as _client_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateSecretRequest(_message.Message):
    __slots__ = ("parent", "secret", "secret_id")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    SECRET_FIELD_NUMBER: _ClassVar[int]
    SECRET_ID_FIELD_NUMBER: _ClassVar[int]
    parent: str
    secret: _secret_pb2.Secret
    secret_id: str
    def __init__(self, parent: _Optional[str] = ..., secret: _Optional[_Union[_secret_pb2.Secret, _Mapping]] = ..., secret_id: _Optional[str] = ...) -> None: ...

class CreateSecretResponse(_message.Message):
    __slots__ = ("secret",)
    SECRET_FIELD_NUMBER: _ClassVar[int]
    secret: _secret_pb2.Secret
    def __init__(self, secret: _Optional[_Union[_secret_pb2.Secret, _Mapping]] = ...) -> None: ...

class GetSecretRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class GetSecretResponse(_message.Message):
    __slots__ = ("secret",)
    SECRET_FIELD_NUMBER: _ClassVar[int]
    secret: _secret_pb2.Secret
    def __init__(self, secret: _Optional[_Union[_secret_pb2.Secret, _Mapping]] = ...) -> None: ...

class ListSecretsRequest(_message.Message):
    __slots__ = ("parent", "page_size", "page_token", "show_deleted")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    SHOW_DELETED_FIELD_NUMBER: _ClassVar[int]
    parent: str
    page_size: int
    page_token: str
    show_deleted: bool
    def __init__(self, parent: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., show_deleted: bool = ...) -> None: ...

class ListSecretsResponse(_message.Message):
    __slots__ = ("secrets", "next_page_token", "total_size")
    SECRETS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    secrets: _containers.RepeatedCompositeFieldContainer[_secret_pb2.Secret]
    next_page_token: str
    total_size: int
    def __init__(self, secrets: _Optional[_Iterable[_Union[_secret_pb2.Secret, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...

class DeleteSecretRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class DeleteSecretResponse(_message.Message):
    __slots__ = ("secret",)
    SECRET_FIELD_NUMBER: _ClassVar[int]
    secret: _secret_pb2.Secret
    def __init__(self, secret: _Optional[_Union[_secret_pb2.Secret, _Mapping]] = ...) -> None: ...

class UndeleteSecretRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class UndeleteSecretResponse(_message.Message):
    __slots__ = ("secret",)
    SECRET_FIELD_NUMBER: _ClassVar[int]
    secret: _secret_pb2.Secret
    def __init__(self, secret: _Optional[_Union[_secret_pb2.Secret, _Mapping]] = ...) -> None: ...



import http

import pytest

from h2o_secure_store.clients.base.workspace import DEFAULT_WORKSPACE
from h2o_secure_store.clients.secret_version.client import SecretVersionClient
from h2o_secure_store.clients.secret_version.secret_version import SecretVersion
from h2o_secure_store.exception import CustomApiException


def test_reveal_secret_version(
        delete_secret_rows_before,
        secret_user,
        user_secret_version_client: SecretVersionClient,
):
    secret_version = user_secret_version_client.create_secret_version(
        parent=secret_user.name,
        secret_version=SecretVersion(
            value=b"secret_value"
        ),
    )

    secret_version_value = user_secret_version_client.reveal_secret_version_value(
        name=f"{DEFAULT_WORKSPACE}/secrets/{secret_user.get_secret_id()}/versions/{secret_version.get_secret_version_id()}"
    )

    assert secret_version_value == b"secret_value"


def test_reveal_latest_secret_version(
        delete_secret_rows_before,
        secret_user,
        user_secret_version_client: SecretVersionClient,
):
    latest_secret_value = b"secret_value_latest"

    user_secret_version_client.create_secret_version(
        parent=secret_user.name,
        secret_version=SecretVersion(
            value=b"secret_value"
        ),
    )

    user_secret_version_client.create_secret_version(
        parent=secret_user.name,
        secret_version=SecretVersion(
            value=latest_secret_value
        ),
    )

    secret_version_value = user_secret_version_client.reveal_secret_version_value(
        name=f"{DEFAULT_WORKSPACE}/secrets/{secret_user.get_secret_id()}/versions/latest"
    )

    assert secret_version_value == latest_secret_value


def test_reveal_secret_version_not_found(
        delete_secret_rows_before,
        secret_user,
        user_secret_version_client: SecretVersionClient,
):
    with pytest.raises(CustomApiException) as exc:
        user_secret_version_client.reveal_secret_version_value(
            name=f"{DEFAULT_WORKSPACE}/secrets/{secret_user.get_secret_id()}/versions/non-existent"
        )
    assert exc.value.status == http.HTTPStatus.NOT_FOUND


def test_reveal_latest_secret_version_not_found(
        delete_secret_rows_before,
        secret_user,
        user_secret_version_client: SecretVersionClient,
):
    with pytest.raises(CustomApiException) as exc:
        user_secret_version_client.reveal_secret_version_value(
            name=f"{DEFAULT_WORKSPACE}/secrets/{secret_user.get_secret_id()}/versions/latest"
        )
    assert exc.value.status == http.HTTPStatus.NOT_FOUND


def test_reveal_secret_version_not_found_parent(
        delete_secret_rows_before,
        user_secret_version_client: SecretVersionClient,
):
    with pytest.raises(CustomApiException) as exc:
        user_secret_version_client.reveal_secret_version_value(
            name=f"{DEFAULT_WORKSPACE}/secrets/non-existent/versions/non-existent"
        )
    assert exc.value.status == http.HTTPStatus.NOT_FOUND



import os

import psycopg2
import pytest as pytest

import h2o_secure_store


@pytest.fixture(scope="session")
def super_admin_clients():
    return h2o_secure_store.login_custom(
        endpoint=os.getenv("SECURE_STORE_SERVER_URL"),
        refresh_token=os.getenv("PLATFORM_TOKEN_SUPER_ADMIN"),
        issuer_url=os.getenv("PLATFORM_OIDC_URL"),
        client_id=os.getenv("PLATFORM_OIDC_CLIENT_ID"),
    )


@pytest.fixture(scope="session")
def user_clients():
    return h2o_secure_store.login_custom(
        endpoint=os.getenv("SECURE_STORE_SERVER_URL"),
        refresh_token=os.getenv("PLATFORM_TOKEN_USER"),
        issuer_url=os.getenv("PLATFORM_OIDC_URL"),
        client_id=os.getenv("PLATFORM_OIDC_CLIENT_ID"),
    )


@pytest.fixture(scope="session")
def db_connection():
    conn_string =os.getenv("POSTGRES_DSN")
    return psycopg2.connect(conn_string)


@pytest.fixture(scope="session")
def super_admin_oauth_client_client(super_admin_clients):
    return super_admin_clients.oauth_client_client


@pytest.fixture(scope="session")
def super_admin_token_source_client(super_admin_clients):
    return super_admin_clients.token_source_client


@pytest.fixture(scope="session")
def user_token_source_client(user_clients):
    return user_clients.token_source_client


@pytest.fixture(scope="session")
def user_secret_client(user_clients):
    return user_clients.secret_client


@pytest.fixture(scope="session")
def super_admin_secret_client(super_admin_clients):
    return super_admin_clients.secret_client


@pytest.fixture(scope="session")
def user_secret_version_client(user_clients):
    return user_clients.secret_version_client


@pytest.fixture(scope="function")
def delete_all_oauth_clients_before_after(super_admin_oauth_client_client):
    super_admin_oauth_client_client.delete_all_oauth_clients()
    yield
    super_admin_oauth_client_client.delete_all_oauth_clients()


@pytest.fixture(scope="function")
def delete_all_token_sources_before_after(user_token_source_client, oauth_client1):
    user_token_source_client.delete_all_token_sources(oauth_client_id=oauth_client1.oauth_client_id)
    yield
    user_token_source_client.delete_all_token_sources(oauth_client_id=oauth_client1.oauth_client_id)


@pytest.fixture(scope="function")
def delete_secret_rows_before(db_connection):
    cursor = db_connection.cursor()
    cursor.execute("DELETE FROM secret;")
    db_connection.commit()
    cursor.close()


@pytest.fixture(scope="function")
def secret_user(user_secret_client):
    return user_secret_client.create_secret(
        parent="workspaces/default",
    )


@pytest.fixture(scope="function")
def oauth_client1(super_admin_oauth_client_client):
    oauth_client = super_admin_oauth_client_client.create_oauth_client(
        issuer="issuer1",
        client_id="client1",
        oauth_client_id="oauth-client1",
        authorization_endpoint="authz-endpoint",
        token_endpoint="token-endpoint",
    )
    yield oauth_client
    super_admin_oauth_client_client.delete_oauth_client(oauth_client_id="oauth-client1")


@pytest.fixture(scope="function")
def oauth_client2(super_admin_oauth_client_client):
    oauth_client = super_admin_oauth_client_client.create_oauth_client(
        issuer="issuer1",
        client_id="client2",
        oauth_client_id="oauth-client2",
        authorization_endpoint="authz-endpoint",
        token_endpoint="token-endpoint",
    )
    yield oauth_client
    super_admin_oauth_client_client.delete_oauth_client(oauth_client_id="oauth-client2")


@pytest.fixture(scope="function")
def oauth_client3(super_admin_oauth_client_client):
    oauth_client = super_admin_oauth_client_client.create_oauth_client(
        issuer="issuer1",
        client_id="client3",
        oauth_client_id="oauth-client3",
        authorization_endpoint="authz-endpoint",
        token_endpoint="token-endpoint",
    )
    yield oauth_client
    super_admin_oauth_client_client.delete_oauth_client(oauth_client_id="oauth-client3")


@pytest.fixture(scope="function")
def token_source1(user_token_source_client, oauth_client1):
    token_source = user_token_source_client.create_token_source(
        oauth_client_id=oauth_client1.oauth_client_id,
        redirect_uri="http://localhost:8080",
        token_source_id="token-source1",
    )
    yield token_source
    user_token_source_client.delete_token_source(
        token_source_id="token-source1", oauth_client_id=oauth_client1.oauth_client_id
    )


@pytest.fixture(scope="function")
def token_source2(user_token_source_client, oauth_client1):
    token_source = user_token_source_client.create_token_source(
        oauth_client_id=oauth_client1.oauth_client_id,
        redirect_uri="http://localhost:8080",
        token_source_id="token-source2",
    )
    yield token_source
    user_token_source_client.delete_token_source(
        token_source_id="token-source2", oauth_client_id=oauth_client1.oauth_client_id
    )


@pytest.fixture(scope="function")
def token_source3(user_token_source_client, oauth_client1):
    token_source = user_token_source_client.create_token_source(
        oauth_client_id=oauth_client1.oauth_client_id,
        redirect_uri="http://localhost:8080",
        token_source_id="token-source3",
    )
    yield token_source
    user_token_source_client.delete_token_source(
        token_source_id="token-source3", oauth_client_id=oauth_client1.oauth_client_id
    )


from h2o_secure_store.gen.ai.h2o.securestore.v1 import token_source_pb2 as _token_source_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.api import resource_pb2 as _resource_pb2
from google.api import client_pb2 as _client_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateTokenSourceRequest(_message.Message):
    __slots__ = ("parent", "token_source", "token_source_id")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    TOKEN_SOURCE_FIELD_NUMBER: _ClassVar[int]
    TOKEN_SOURCE_ID_FIELD_NUMBER: _ClassVar[int]
    parent: str
    token_source: _token_source_pb2.TokenSource
    token_source_id: str
    def __init__(self, parent: _Optional[str] = ..., token_source: _Optional[_Union[_token_source_pb2.TokenSource, _Mapping]] = ..., token_source_id: _Optional[str] = ...) -> None: ...

class CreateTokenSourceResponse(_message.Message):
    __slots__ = ("token_source",)
    TOKEN_SOURCE_FIELD_NUMBER: _ClassVar[int]
    token_source: _token_source_pb2.TokenSource
    def __init__(self, token_source: _Optional[_Union[_token_source_pb2.TokenSource, _Mapping]] = ...) -> None: ...

class GetTokenSourceRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class GetTokenSourceResponse(_message.Message):
    __slots__ = ("token_source",)
    TOKEN_SOURCE_FIELD_NUMBER: _ClassVar[int]
    token_source: _token_source_pb2.TokenSource
    def __init__(self, token_source: _Optional[_Union[_token_source_pb2.TokenSource, _Mapping]] = ...) -> None: ...

class ListTokenSourcesRequest(_message.Message):
    __slots__ = ("parent", "page_size", "page_token")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    parent: str
    page_size: int
    page_token: str
    def __init__(self, parent: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class ListTokenSourcesResponse(_message.Message):
    __slots__ = ("token_sources", "next_page_token")
    TOKEN_SOURCES_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    token_sources: _containers.RepeatedCompositeFieldContainer[_token_source_pb2.TokenSource]
    next_page_token: str
    def __init__(self, token_sources: _Optional[_Iterable[_Union[_token_source_pb2.TokenSource, _Mapping]]] = ..., next_page_token: _Optional[str] = ...) -> None: ...

class DeleteTokenSourceRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class DeleteTokenSourceResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ai/h2o/securestore/v1/token_source_service.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from h2o_secure_store.gen.ai.h2o.securestore.v1 import token_source_pb2 as ai_dot_h2o_dot_securestore_dot_v1_dot_token__source__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0ai/h2o/securestore/v1/token_source_service.proto\x12\x15\x61i.h2o.securestore.v1\x1a(ai/h2o/securestore/v1/token_source.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/api/resource.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\"\xd6\x01\n\x18\x43reateTokenSourceRequest\x12?\n\x06parent\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \x12\x1esecurestore.h2o.ai/OAuthClientR\x06parent\x12K\n\x0ctoken_source\x18\x02 \x01(\x0b\x32\".ai.h2o.securestore.v1.TokenSourceB\x04\xe2\x41\x01\x02R\x0btokenSource\x12,\n\x0ftoken_source_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\rtokenSourceId\"b\n\x19\x43reateTokenSourceResponse\x12\x45\n\x0ctoken_source\x18\x01 \x01(\x0b\x32\".ai.h2o.securestore.v1.TokenSourceR\x0btokenSource\"T\n\x15GetTokenSourceRequest\x12;\n\x04name\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \n\x1esecurestore.h2o.ai/TokenSourceR\x04name\"_\n\x16GetTokenSourceResponse\x12\x45\n\x0ctoken_source\x18\x01 \x01(\x0b\x32\".ai.h2o.securestore.v1.TokenSourceR\x0btokenSource\"\xa2\x01\n\x17ListTokenSourcesRequest\x12?\n\x06parent\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \x12\x1esecurestore.h2o.ai/TokenSourceR\x06parent\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x8b\x01\n\x18ListTokenSourcesResponse\x12G\n\rtoken_sources\x18\x01 \x03(\x0b\x32\".ai.h2o.securestore.v1.TokenSourceR\x0ctokenSources\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"W\n\x18\x44\x65leteTokenSourceRequest\x12;\n\x04name\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \n\x1esecurestore.h2o.ai/TokenSourceR\x04name\"\x1b\n\x19\x44\x65leteTokenSourceResponse2\xff\x05\n\x12TokenSourceService\x12\xdc\x01\n\x11\x43reateTokenSource\x12/.ai.h2o.securestore.v1.CreateTokenSourceRequest\x1a\x30.ai.h2o.securestore.v1.CreateTokenSourceResponse\"d\xda\x41#parent,token_source,token_source_id\x82\xd3\xe4\x93\x02\x38\"(/v1/{parent=oauthClients/*}/tokenSources:\x0ctoken_source\x12\xa6\x01\n\x0eGetTokenSource\x12,.ai.h2o.securestore.v1.GetTokenSourceRequest\x1a-.ai.h2o.securestore.v1.GetTokenSourceResponse\"7\xda\x41\x04name\x82\xd3\xe4\x93\x02*\x12(/v1/{name=oauthClients/*/tokenSources/*}\x12\xae\x01\n\x10ListTokenSources\x12..ai.h2o.securestore.v1.ListTokenSourcesRequest\x1a/.ai.h2o.securestore.v1.ListTokenSourcesResponse\"9\xda\x41\x06parent\x82\xd3\xe4\x93\x02*\x12(/v1/{parent=oauthClients/*}/tokenSources\x12\xaf\x01\n\x11\x44\x65leteTokenSource\x12/.ai.h2o.securestore.v1.DeleteTokenSourceRequest\x1a\x30.ai.h2o.securestore.v1.DeleteTokenSourceResponse\"7\xda\x41\x04name\x82\xd3\xe4\x93\x02**(/v1/{name=oauthClients/*/tokenSources/*}B\xf2\x01\n\x19\x63om.ai.h2o.securestore.v1B\x17TokenSourceServiceProtoP\x01ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\xa2\x02\x03\x41HS\xaa\x02\x15\x41i.H2o.Securestore.V1\xca\x02\x15\x41i\\H2o\\Securestore\\V1\xe2\x02!Ai\\H2o\\Securestore\\V1\\GPBMetadata\xea\x02\x18\x41i::H2o::Securestore::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.h2o.securestore.v1.token_source_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.ai.h2o.securestore.v1B\027TokenSourceServiceProtoP\001ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\242\002\003AHS\252\002\025Ai.H2o.Securestore.V1\312\002\025Ai\\H2o\\Securestore\\V1\342\002!Ai\\H2o\\Securestore\\V1\\GPBMetadata\352\002\030Ai::H2o::Securestore::V1'
  _globals['_CREATETOKENSOURCEREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATETOKENSOURCEREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A \022\036securestore.h2o.ai/OAuthClient'
  _globals['_CREATETOKENSOURCEREQUEST'].fields_by_name['token_source']._loaded_options = None
  _globals['_CREATETOKENSOURCEREQUEST'].fields_by_name['token_source']._serialized_options = b'\342A\001\002'
  _globals['_CREATETOKENSOURCEREQUEST'].fields_by_name['token_source_id']._loaded_options = None
  _globals['_CREATETOKENSOURCEREQUEST'].fields_by_name['token_source_id']._serialized_options = b'\342A\001\001'
  _globals['_GETTOKENSOURCEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETTOKENSOURCEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A \n\036securestore.h2o.ai/TokenSource'
  _globals['_LISTTOKENSOURCESREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTTOKENSOURCESREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A \022\036securestore.h2o.ai/TokenSource'
  _globals['_LISTTOKENSOURCESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTTOKENSOURCESREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTTOKENSOURCESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTTOKENSOURCESREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_DELETETOKENSOURCEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETETOKENSOURCEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A \n\036securestore.h2o.ai/TokenSource'
  _globals['_TOKENSOURCESERVICE'].methods_by_name['CreateTokenSource']._loaded_options = None
  _globals['_TOKENSOURCESERVICE'].methods_by_name['CreateTokenSource']._serialized_options = b'\332A#parent,token_source,token_source_id\202\323\344\223\0028\"(/v1/{parent=oauthClients/*}/tokenSources:\014token_source'
  _globals['_TOKENSOURCESERVICE'].methods_by_name['GetTokenSource']._loaded_options = None
  _globals['_TOKENSOURCESERVICE'].methods_by_name['GetTokenSource']._serialized_options = b'\332A\004name\202\323\344\223\002*\022(/v1/{name=oauthClients/*/tokenSources/*}'
  _globals['_TOKENSOURCESERVICE'].methods_by_name['ListTokenSources']._loaded_options = None
  _globals['_TOKENSOURCESERVICE'].methods_by_name['ListTokenSources']._serialized_options = b'\332A\006parent\202\323\344\223\002*\022(/v1/{parent=oauthClients/*}/tokenSources'
  _globals['_TOKENSOURCESERVICE'].methods_by_name['DeleteTokenSource']._loaded_options = None
  _globals['_TOKENSOURCESERVICE'].methods_by_name['DeleteTokenSource']._serialized_options = b'\332A\004name\202\323\344\223\002**(/v1/{name=oauthClients/*/tokenSources/*}'
  _globals['_CREATETOKENSOURCEREQUEST']._serialized_start=233
  _globals['_CREATETOKENSOURCEREQUEST']._serialized_end=447
  _globals['_CREATETOKENSOURCERESPONSE']._serialized_start=449
  _globals['_CREATETOKENSOURCERESPONSE']._serialized_end=547
  _globals['_GETTOKENSOURCEREQUEST']._serialized_start=549
  _globals['_GETTOKENSOURCEREQUEST']._serialized_end=633
  _globals['_GETTOKENSOURCERESPONSE']._serialized_start=635
  _globals['_GETTOKENSOURCERESPONSE']._serialized_end=730
  _globals['_LISTTOKENSOURCESREQUEST']._serialized_start=733
  _globals['_LISTTOKENSOURCESREQUEST']._serialized_end=895
  _globals['_LISTTOKENSOURCESRESPONSE']._serialized_start=898
  _globals['_LISTTOKENSOURCESRESPONSE']._serialized_end=1037
  _globals['_DELETETOKENSOURCEREQUEST']._serialized_start=1039
  _globals['_DELETETOKENSOURCEREQUEST']._serialized_end=1126
  _globals['_DELETETOKENSOURCERESPONSE']._serialized_start=1128
  _globals['_DELETETOKENSOURCERESPONSE']._serialized_end=1155
  _globals['_TOKENSOURCESERVICE']._serialized_start=1158
  _globals['_TOKENSOURCESERVICE']._serialized_end=1925
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ai/h2o/securestore/v1/secret_version.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ai/h2o/securestore/v1/secret_version.proto\x12\x15\x61i.h2o.securestore.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc5\x02\n\rSecretVersion\x12\x19\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x08\x03R\x04name\x12\x1b\n\x05value\x18\x02 \x01(\x0c\x42\x05\xe2\x41\x02\x02\x04R\x05value\x12\x1e\n\x07\x63reator\x18\x03 \x01(\tB\x04\xe2\x41\x01\x03R\x07\x63reator\x12\x41\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12\x16\n\x03uid\x18\x05 \x01(\tB\x04\xe2\x41\x01\x03R\x03uid:\x80\x01\xea\x41}\n securestore.h2o.ai/SecretVersion\x12:workspaces/{workspace}/secrets/{secret}/versions/{version}*\x0esecretVersions2\rsecretVersionB\xed\x01\n\x19\x63om.ai.h2o.securestore.v1B\x12SecretVersionProtoP\x01ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\xa2\x02\x03\x41HS\xaa\x02\x15\x41i.H2o.Securestore.V1\xca\x02\x15\x41i\\H2o\\Securestore\\V1\xe2\x02!Ai\\H2o\\Securestore\\V1\\GPBMetadata\xea\x02\x18\x41i::H2o::Securestore::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.h2o.securestore.v1.secret_version_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.ai.h2o.securestore.v1B\022SecretVersionProtoP\001ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\242\002\003AHS\252\002\025Ai.H2o.Securestore.V1\312\002\025Ai\\H2o\\Securestore\\V1\342\002!Ai\\H2o\\Securestore\\V1\\GPBMetadata\352\002\030Ai::H2o::Securestore::V1'
  _globals['_SECRETVERSION'].fields_by_name['name']._loaded_options = None
  _globals['_SECRETVERSION'].fields_by_name['name']._serialized_options = b'\342A\002\010\003'
  _globals['_SECRETVERSION'].fields_by_name['value']._loaded_options = None
  _globals['_SECRETVERSION'].fields_by_name['value']._serialized_options = b'\342A\002\002\004'
  _globals['_SECRETVERSION'].fields_by_name['creator']._loaded_options = None
  _globals['_SECRETVERSION'].fields_by_name['creator']._serialized_options = b'\342A\001\003'
  _globals['_SECRETVERSION'].fields_by_name['create_time']._loaded_options = None
  _globals['_SECRETVERSION'].fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _globals['_SECRETVERSION'].fields_by_name['uid']._loaded_options = None
  _globals['_SECRETVERSION'].fields_by_name['uid']._serialized_options = b'\342A\001\003'
  _globals['_SECRETVERSION']._loaded_options = None
  _globals['_SECRETVERSION']._serialized_options = b'\352A}\n securestore.h2o.ai/SecretVersion\022:workspaces/{workspace}/secrets/{secret}/versions/{version}*\016secretVersions2\rsecretVersion'
  _globals['_SECRETVERSION']._serialized_start=163
  _globals['_SECRETVERSION']._serialized_end=488
# @@protoc_insertion_point(module_scope)



from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.api import resource_pb2 as _resource_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Secret(_message.Message):
    __slots__ = ("name", "state", "creator", "deleter", "create_time", "delete_time", "purge_time", "uid", "annotations", "display_name")
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        STATE_UNSPECIFIED: _ClassVar[Secret.State]
        STATE_ACTIVE: _ClassVar[Secret.State]
        STATE_DELETED: _ClassVar[Secret.State]
    STATE_UNSPECIFIED: Secret.State
    STATE_ACTIVE: Secret.State
    STATE_DELETED: Secret.State
    class AnnotationsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    DELETER_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    DELETE_TIME_FIELD_NUMBER: _ClassVar[int]
    PURGE_TIME_FIELD_NUMBER: _ClassVar[int]
    UID_FIELD_NUMBER: _ClassVar[int]
    ANNOTATIONS_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    state: Secret.State
    creator: str
    deleter: str
    create_time: _timestamp_pb2.Timestamp
    delete_time: _timestamp_pb2.Timestamp
    purge_time: _timestamp_pb2.Timestamp
    uid: str
    annotations: _containers.ScalarMap[str, str]
    display_name: str
    def __init__(self, name: _Optional[str] = ..., state: _Optional[_Union[Secret.State, str]] = ..., creator: _Optional[str] = ..., deleter: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., delete_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., purge_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., uid: _Optional[str] = ..., annotations: _Optional[_Mapping[str, str]] = ..., display_name: _Optional[str] = ...) -> None: ...



from h2o_secure_store.gen.ai.h2o.securestore.v1 import oauth_client_pb2 as _oauth_client_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.api import resource_pb2 as _resource_pb2
from google.api import client_pb2 as _client_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf import field_mask_pb2 as _field_mask_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateOAuthClientRequest(_message.Message):
    __slots__ = ("oauth_client", "oauth_client_id")
    OAUTH_CLIENT_FIELD_NUMBER: _ClassVar[int]
    OAUTH_CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    oauth_client: _oauth_client_pb2.OAuthClient
    oauth_client_id: str
    def __init__(self, oauth_client: _Optional[_Union[_oauth_client_pb2.OAuthClient, _Mapping]] = ..., oauth_client_id: _Optional[str] = ...) -> None: ...

class CreateOAuthClientResponse(_message.Message):
    __slots__ = ("oauth_client",)
    OAUTH_CLIENT_FIELD_NUMBER: _ClassVar[int]
    oauth_client: _oauth_client_pb2.OAuthClient
    def __init__(self, oauth_client: _Optional[_Union[_oauth_client_pb2.OAuthClient, _Mapping]] = ...) -> None: ...

class GetOAuthClientRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class GetOAuthClientResponse(_message.Message):
    __slots__ = ("oauth_client",)
    OAUTH_CLIENT_FIELD_NUMBER: _ClassVar[int]
    oauth_client: _oauth_client_pb2.OAuthClient
    def __init__(self, oauth_client: _Optional[_Union[_oauth_client_pb2.OAuthClient, _Mapping]] = ...) -> None: ...

class ListOAuthClientsRequest(_message.Message):
    __slots__ = ("page_size", "page_token")
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    page_size: int
    page_token: str
    def __init__(self, page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class ListOAuthClientsResponse(_message.Message):
    __slots__ = ("oauth_clients", "next_page_token")
    OAUTH_CLIENTS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    oauth_clients: _containers.RepeatedCompositeFieldContainer[_oauth_client_pb2.OAuthClient]
    next_page_token: str
    def __init__(self, oauth_clients: _Optional[_Iterable[_Union[_oauth_client_pb2.OAuthClient, _Mapping]]] = ..., next_page_token: _Optional[str] = ...) -> None: ...

class UpdateOAuthClientRequest(_message.Message):
    __slots__ = ("oauth_client", "update_mask")
    OAUTH_CLIENT_FIELD_NUMBER: _ClassVar[int]
    UPDATE_MASK_FIELD_NUMBER: _ClassVar[int]
    oauth_client: _oauth_client_pb2.OAuthClient
    update_mask: _field_mask_pb2.FieldMask
    def __init__(self, oauth_client: _Optional[_Union[_oauth_client_pb2.OAuthClient, _Mapping]] = ..., update_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class UpdateOAuthClientResponse(_message.Message):
    __slots__ = ("oauth_client",)
    OAUTH_CLIENT_FIELD_NUMBER: _ClassVar[int]
    oauth_client: _oauth_client_pb2.OAuthClient
    def __init__(self, oauth_client: _Optional[_Union[_oauth_client_pb2.OAuthClient, _Mapping]] = ...) -> None: ...

class DeleteOAuthClientRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class DeleteOAuthClientResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class InvalidateTokenSourcesRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class InvalidateTokenSourcesResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ai/h2o/securestore/v1/token_source.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ai/h2o/securestore/v1/token_source.proto\x12\x15\x61i.h2o.securestore.v1\x1a\x19google/api/resource.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x92\x06\n\x0bTokenSource\x12\x19\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x08\x03R\x04name\x12(\n\x0credirect_uri\x18\x02 \x01(\tB\x05\xe2\x41\x02\x01\x05R\x0bredirectUri\x12!\n\tlogin_uri\x18\x03 \x01(\tB\x04\xe2\x41\x01\x03R\x08loginUri\x12+\n\x0elogin_required\x18\x04 \x01(\x08\x42\x04\xe2\x41\x01\x03R\rloginRequired\x12(\n\x0c\x61\x63\x63\x65ss_token\x18\x05 \x01(\tB\x05\xe2\x41\x02\x01\x03R\x0b\x61\x63\x63\x65ssToken\x12\x45\n\nissue_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x01\x03H\x00R\tissueTime\x88\x01\x01\x12\x46\n\x0b\x65xpire_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03H\x01R\nexpireTime\x88\x01\x01\x12\x1e\n\x07subject\x18\x08 \x01(\tB\x04\xe2\x41\x01\x03R\x07subject\x12.\n\x0flogin_principal\x18\t \x01(\tB\x05\xe2\x41\x02\x01\x03R\x0eloginPrincipal\x12\x1e\n\x07\x63reator\x18\n \x01(\tB\x04\xe2\x41\x01\x03R\x07\x63reator\x12\x41\n\x0b\x63reate_time\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12\x45\n\nlogin_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x01\x03H\x02R\tloginTime\x88\x01\x01\x12\x16\n\x03uid\x18\r \x01(\tB\x04\xe2\x41\x01\x03R\x03uid:u\xea\x41r\n\x1esecurestore.h2o.ai/TokenSource\x12\x35oauthClients/{oauthClient}/tokenSources/{tokenSource}*\x0ctokenSources2\x0btokenSourceB\r\n\x0b_issue_timeB\x0e\n\x0c_expire_timeB\r\n\x0b_login_timeB\xeb\x01\n\x19\x63om.ai.h2o.securestore.v1B\x10TokenSourceProtoP\x01ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\xa2\x02\x03\x41HS\xaa\x02\x15\x41i.H2o.Securestore.V1\xca\x02\x15\x41i\\H2o\\Securestore\\V1\xe2\x02!Ai\\H2o\\Securestore\\V1\\GPBMetadata\xea\x02\x18\x41i::H2o::Securestore::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.h2o.securestore.v1.token_source_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.ai.h2o.securestore.v1B\020TokenSourceProtoP\001ZEgithub.com/h2oai/secure-store/api/ai/h2o/securestore/v1;securestorev1\242\002\003AHS\252\002\025Ai.H2o.Securestore.V1\312\002\025Ai\\H2o\\Securestore\\V1\342\002!Ai\\H2o\\Securestore\\V1\\GPBMetadata\352\002\030Ai::H2o::Securestore::V1'
  _globals['_TOKENSOURCE'].fields_by_name['name']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['name']._serialized_options = b'\342A\002\010\003'
  _globals['_TOKENSOURCE'].fields_by_name['redirect_uri']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['redirect_uri']._serialized_options = b'\342A\002\001\005'
  _globals['_TOKENSOURCE'].fields_by_name['login_uri']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['login_uri']._serialized_options = b'\342A\001\003'
  _globals['_TOKENSOURCE'].fields_by_name['login_required']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['login_required']._serialized_options = b'\342A\001\003'
  _globals['_TOKENSOURCE'].fields_by_name['access_token']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['access_token']._serialized_options = b'\342A\002\001\003'
  _globals['_TOKENSOURCE'].fields_by_name['issue_time']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['issue_time']._serialized_options = b'\342A\002\001\003'
  _globals['_TOKENSOURCE'].fields_by_name['expire_time']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['expire_time']._serialized_options = b'\342A\001\003'
  _globals['_TOKENSOURCE'].fields_by_name['subject']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['subject']._serialized_options = b'\342A\001\003'
  _globals['_TOKENSOURCE'].fields_by_name['login_principal']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['login_principal']._serialized_options = b'\342A\002\001\003'
  _globals['_TOKENSOURCE'].fields_by_name['creator']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['creator']._serialized_options = b'\342A\001\003'
  _globals['_TOKENSOURCE'].fields_by_name['create_time']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['create_time']._serialized_options = b'\342A\001\003'
  _globals['_TOKENSOURCE'].fields_by_name['login_time']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['login_time']._serialized_options = b'\342A\002\001\003'
  _globals['_TOKENSOURCE'].fields_by_name['uid']._loaded_options = None
  _globals['_TOKENSOURCE'].fields_by_name['uid']._serialized_options = b'\342A\001\003'
  _globals['_TOKENSOURCE']._loaded_options = None
  _globals['_TOKENSOURCE']._serialized_options = b'\352Ar\n\036securestore.h2o.ai/TokenSource\0225oauthClients/{oauthClient}/tokenSources/{tokenSource}*\014tokenSources2\013tokenSource'
  _globals['_TOKENSOURCE']._serialized_start=161
  _globals['_TOKENSOURCE']._serialized_end=947
# @@protoc_insertion_point(module_scope)
